@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,8 +21,7 @@
 #include "pimcommon_export.h"
 #include <QListWidget>
 
-namespace PimCommon
-{
+namespace PimCommon {
 class TemplateListWidgetPrivate;
 
 struct defaultTemplate {
@@ -65,16 +64,6 @@ Q_SIGNALS:
 private:
     friend class TemplateListWidgetPrivate;
     TemplateListWidgetPrivate *const d;
-    Q_PRIVATE_SLOT(d, void slotAdd())
-    Q_PRIVATE_SLOT(d, void slotRemove())
-    Q_PRIVATE_SLOT(d, void slotModify())
-    Q_PRIVATE_SLOT(d, void slotInsertTemplate())
-    Q_PRIVATE_SLOT(d, void slotContextMenu(const QPoint &pos))
-    Q_PRIVATE_SLOT(d, void slotInsertNewTemplate(const QString &))
-    Q_PRIVATE_SLOT(d, void slotExportTemplates())
-    Q_PRIVATE_SLOT(d, void slotImportTemplates())
-    Q_PRIVATE_SLOT(d, void slotDuplicate())
-    Q_PRIVATE_SLOT(d, void slotDownloadTemplates())
 };
 }
 Q_DECLARE_TYPEINFO(PimCommon::defaultTemplate, Q_MOVABLE_TYPE);
