@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,8 +22,7 @@
 #include "pimcommon_export.h"
 class QPaintEvent;
 class QEvent;
-namespace PimCommon
-{
+namespace PimCommon {
 class PIMCOMMON_EXPORT CustomTreeView : public QTreeWidget
 {
     Q_OBJECT
