@@ -18,27 +18,27 @@
  */
 
 #include "aclmanager.h"
-
-#include "pimcommonakonadi_debug.h"
 #include "aclentrydialog_p.h"
 #include "aclutils_p.h"
+#include "aclmodifyjob.h"
 #include "imapaclattribute.h"
 #include "imapresourcesettings.h"
+#include "pimcommonakonadi_debug.h"
 #include "util/pimutil.h"
-#include <Collection>
-#include <CollectionFetchJob>
-#include <CollectionModifyJob>
+
+#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/ServerManager>
 #include <Akonadi/Contact/ContactGroupExpandJob>
 #include <Akonadi/Contact/ContactGroupSearchJob>
-#include <AkonadiCore/ServerManager>
-#include "aclmodifyjob.h"
-#include <KEmailAddress>
 
+#include <KEmailAddress>
 #include <KLocalizedString>
 #include <KMessageBox>
 
 #include <QAbstractListModel>
 #include <QAction>
+#include <QDBusInterface>
+#include <QDBusReply>
 #include <QItemSelectionModel>
 
 using namespace PimCommon;
@@ -77,18 +77,16 @@ public:
         default:
             return QVariant();
         }
-
     }
 
-    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override {
-        if (index.row() < 0 || index.row() >= mRights.count())
-        {
+    bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override
+    {
+        if (index.row() < 0 || index.row() >= mRights.count()) {
             return false;
         }
 
         QPair<QByteArray, KIMAP::Acl::Rights> &right = mRights[ index.row() ];
-        switch (role)
-        {
+        switch (role) {
         case UserIdRole:
             right.first = value.toByteArray();
             Q_EMIT dataChanged(index, index);
@@ -144,10 +142,10 @@ public:
     }
 
 protected:
-    bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override {
+    bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override
+    {
         beginInsertRows(parent, row, row + count - 1);
-        for (int i = 0; i < count; ++i)
-        {
+        for (int i = 0; i < count; ++i) {
             mRights.insert(row, qMakePair(QByteArray(), KIMAP::Acl::Rights()));
         }
         endInsertRows();
@@ -155,10 +153,10 @@ protected:
         return true;
     }
 
-    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override {
+    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override
+    {
         beginRemoveRows(parent, row, row + count - 1);
-        for (int i = 0; i < count; ++i)
-        {
+        for (int i = 0; i < count; ++i) {
             mRights.remove(row, count);
         }
         endRemoveRows();
@@ -174,28 +172,32 @@ class Q_DECL_HIDDEN PimCommon::AclManager::Private
 {
 public:
     Private(AclManager *qq)
-        : q(qq),
-          mChanged(false)
+        : q(qq)
+        , mChanged(false)
     {
         mAddAction = new QAction(i18n("Add Entry..."), q);
-        q->connect(mAddAction, SIGNAL(triggered(bool)),
-                   q, SLOT(addAcl()));
+        q->connect(mAddAction, &QAction::triggered, q, [this]() {
+            addAcl();
+        });
 
         mEditAction = new QAction(i18n("Edit Entry..."), q);
         mEditAction->setEnabled(false);
-        q->connect(mEditAction, SIGNAL(triggered(bool)),
-                   q, SLOT(editAcl()));
+        q->connect(mEditAction, &QAction::triggered, q, [this]() {
+            editAcl();
+        });
 
         mDeleteAction = new QAction(i18n("Remove Entry"), q);
         mDeleteAction->setEnabled(false);
-        q->connect(mDeleteAction, SIGNAL(triggered(bool)),
-                   q, SLOT(deleteAcl()));
+        q->connect(mDeleteAction, &QAction::triggered, q, [this]() {
+            deleteAcl();
+        });
 
         mModel = new AclModel(q);
 
         mSelectionModel = new QItemSelectionModel(mModel);
-        q->connect(mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                   q, SLOT(selectionChanged()));
+        q->connect(mSelectionModel, &QItemSelectionModel::selectionChanged, q, [this]() {
+            selectionChanged();
+        });
     }
 
     ~Private()
@@ -212,8 +214,8 @@ public:
         if (canAdmin && itemSelected) {
             const QModelIndex index = mSelectionModel->selectedIndexes().first();
             const QString userId = index.data(AclModel::UserIdRole).toString();
-            const KIMAP::Acl::Rights rights =
-                static_cast<KIMAP::Acl::Rights>(index.data(AclModel::PermissionsRole).toInt());
+            const KIMAP::Acl::Rights rights
+                = static_cast<KIMAP::Acl::Rights>(index.data(AclModel::PermissionsRole).toInt());
 
             // Don't allow users to remove their own admin permissions - there's no way back
             if (mImapUserName == userId && (rights & KIMAP::Acl::Admin)) {
@@ -249,8 +251,8 @@ public:
         if (mEditAction->isEnabled()) {
             const QModelIndex index = mSelectionModel->selectedIndexes().first();
             const QString userId = index.data(AclModel::UserIdRole).toString();
-            const KIMAP::Acl::Rights permissions =
-                static_cast<KIMAP::Acl::Rights>(index.data(AclModel::PermissionsRole).toInt());
+            const KIMAP::Acl::Rights permissions
+                = static_cast<KIMAP::Acl::Rights>(index.data(AclModel::PermissionsRole).toInt());
 
             AclEntryDialog dlg;
             dlg.setWindowTitle(i18n("Edit ACL"));
@@ -274,17 +276,17 @@ public:
 
         if (mImapUserName == userId) {
             if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(
-                        nullptr,
-                        i18n("Do you really want to remove your own permissions for this folder? "
-                             "You will not be able to access it afterwards."),
-                        i18n("Remove"))) {
+                    nullptr,
+                    i18n("Do you really want to remove your own permissions for this folder? "
+                         "You will not be able to access it afterwards."),
+                    i18n("Remove"))) {
                 return;
             }
         } else {
             if (KMessageBox::Cancel == KMessageBox::warningContinueCancel(
-                        nullptr,
-                        i18n("Do you really want to remove these permissions for this folder?"),
-                        i18n("Remove"))) {
+                    nullptr,
+                    i18n("Do you really want to remove these permissions for this folder?"),
+                    i18n("Remove"))) {
                 return;
             }
         }
@@ -298,16 +300,15 @@ public:
         mCollection = collection;
         mChanged = false;
 
-        const PimCommon::ImapAclAttribute *attribute =
-            collection.attribute<PimCommon::ImapAclAttribute>();
+        const PimCommon::ImapAclAttribute *attribute
+            = collection.attribute<PimCommon::ImapAclAttribute>();
         const QMap<QByteArray, KIMAP::Acl::Rights> rights = attribute->rights();
 
         QString resource = collection.resource();
-        if (resource.contains(QStringLiteral("akonadi_kolabproxy_resource"))) {
-            QString basename(QStringLiteral("org.freedesktop.Akonadi.Agent.akonadi_kolabproxy_resource"));
-            if (Akonadi::ServerManager::hasInstanceIdentifier()) {
-                basename += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
-            }
+        if (resource.contains(QLatin1String("akonadi_kolabproxy_resource"))) {
+            const QString basename = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
+                                                                              QStringLiteral("akonadi_kolabproxy_resource"));
+
             QDBusInterface interface(basename, QStringLiteral("/KolabProxy"));
             if (interface.isValid()) {
                 QDBusReply<QString> reply = interface.call(QStringLiteral("imapResourceForCollection"), collection.remoteId().toLongLong());
@@ -316,8 +317,8 @@ public:
                 }
             }
         }
-        OrgKdeAkonadiImapSettingsInterface *imapSettingsInterface =
-            PimCommon::Util::createImapSettingsInterface(resource);
+        OrgKdeAkonadiImapSettingsInterface *imapSettingsInterface
+            = PimCommon::Util::createImapSettingsInterface(resource);
 
         QString loginName;
         QString serverName;
@@ -350,12 +351,12 @@ public:
         selectionChanged();
     }
 
-    AclManager *q;
-    AclModel *mModel;
-    QItemSelectionModel *mSelectionModel;
-    QAction *mAddAction;
-    QAction *mEditAction;
-    QAction *mDeleteAction;
+    AclManager *q = nullptr;
+    AclModel *mModel = nullptr;
+    QItemSelectionModel *mSelectionModel = nullptr;
+    QAction *mAddAction = nullptr;
+    QAction *mEditAction = nullptr;
+    QAction *mDeleteAction = nullptr;
 
     Akonadi::Collection mCollection;
     QString mImapUserName;
@@ -364,7 +365,8 @@ public:
 };
 
 AclManager::AclManager(QObject *parent)
-    : QObject(parent), d(new Private(this))
+    : QObject(parent)
+    , d(new Private(this))
 {
 }
 
@@ -417,8 +419,8 @@ void AclManager::save(bool recursive)
     }
 
     // refresh the collection, it might be outdated in the meantime
-    Akonadi::CollectionFetchJob *job =
-        new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base);
+    Akonadi::CollectionFetchJob *job
+        = new Akonadi::CollectionFetchJob(d->mCollection, Akonadi::CollectionFetchJob::Base);
     if (!job->exec()) {
         qCDebug(PIMCOMMONAKONADI_LOG) << " collection Fetch error" << job->errorString();
         return;
@@ -439,7 +441,6 @@ void AclManager::save(bool recursive)
     QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator it = rights.cbegin();
     const QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator itEnd = rights.cend();
     for (; it != itEnd; ++it) {
-
         // we can use job->exec() here, it is not a hot path
         Akonadi::ContactGroupSearchJob *searchJob = new Akonadi::ContactGroupSearchJob(this);
         searchJob->setQuery(Akonadi::ContactGroupSearchJob::Name, QString::fromLatin1(it.key()));
@@ -449,13 +450,13 @@ void AclManager::save(bool recursive)
         }
 
         if (!searchJob->contactGroups().isEmpty()) {   // it has been a distribution list
-            Akonadi::ContactGroupExpandJob *expandJob =
-                new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
+            Akonadi::ContactGroupExpandJob *expandJob
+                = new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
             if (expandJob->exec()) {
                 const KContacts::Addressee::List lstContacts = expandJob->contacts();
                 for (const KContacts::Addressee &contact : lstContacts) {
-                    const QByteArray rawEmail =
-                        KEmailAddress::extractEmailAddress(contact.preferredEmail().toUtf8());
+                    const QByteArray rawEmail
+                        = KEmailAddress::extractEmailAddress(contact.preferredEmail().toUtf8());
                     if (!rawEmail.isEmpty()) {
                         newRights[ rawEmail ] = it.value();
                     }
@@ -480,5 +481,4 @@ void AclManager::setChanged(bool b)
     d->mChanged = b;
 }
 
-#include "aclmodifyjob.h"
 #include "moc_aclmanager.cpp"
