@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,8 +24,7 @@
 #include <KIMAP/Acl>
 #include <AkonadiCore/collection.h>
 class KJob;
-namespace PimCommon
-{
+namespace PimCommon {
 class ImapAclAttribute;
 class AclModifyJob : public QObject
 {
@@ -39,20 +38,18 @@ public:
     void setNewRights(const QMap<QByteArray, KIMAP::Acl::Rights> &right);
     void start();
 
-private Q_SLOTS:
+private:
     void slotModifyDone(KJob *job);
     void slotFetchCollectionFinished(const Akonadi::Collection::List &collectionList);
     void slotFetchCollectionFailed();
-
-private:
-    void changeAcl(Akonadi::Collection collection);
+    void changeAcl(const Akonadi::Collection &collection);
     void checkNewCollection();
     bool canAdministrate(PimCommon::ImapAclAttribute *attribute, const Akonadi::Collection &collection) const;
     Akonadi::Collection mTopLevelCollection;
     Akonadi::Collection::List mRecursiveCollection;
     QMap<QByteArray, KIMAP::Acl::Rights> mNewRight;
-    bool mRecursive;
-    int mCurrentIndex;
+    bool mRecursive = false;
+    int mCurrentIndex = -1;
 };
 }
 #endif // ACLMODIFYJOB_H
