@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -33,14 +33,14 @@ public:
     ContentTypeWidgetPrivate()
         : mContentsComboBox(nullptr)
     {
-
     }
-    KComboBox *mContentsComboBox;
+
+    KComboBox *mContentsComboBox = nullptr;
 };
 
 ContentTypeWidget::ContentTypeWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new PimCommon::ContentTypeWidgetPrivate)
+    : QWidget(parent)
+    , d(new PimCommon::ContentTypeWidgetPrivate)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
     hbox->setMargin(0);
@@ -63,7 +63,7 @@ ContentTypeWidget::ContentTypeWidget(QWidget *parent)
     d->mContentsComboBox->addItem(collectionUtil.folderContentDescription(CollectionTypeUtil::ContentsTypeFreebusy));
     d->mContentsComboBox->addItem(collectionUtil.folderContentDescription(CollectionTypeUtil::ContentsTypeFile));
 
-    connect(d->mContentsComboBox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &ContentTypeWidget::activated);
+    connect(d->mContentsComboBox, QOverload<int>::of(&KComboBox::activated), this, &ContentTypeWidget::activated);
 }
 
 ContentTypeWidget::~ContentTypeWidget()
